/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
#ifndef _BONOBO_MONIKER_ITEM_H_
#define _BONOBO_MONIKER_ITEM_H_

BEGIN_GNOME_DECLS

#define BONOBO_MONIKER_ITEM_TYPE        (bonobo_moniker_item_get_type ())
#define BONOBO_MONIKER_ITEM(o)          (GTK_CHECK_CAST ((o), BONOBO_MONIKER_ITEM_TYPE, BonoboMonikerItem))
#define BONOBO_MONIKER_ITEM_CLASS(k)    (GTK_CHECK_CLASS_CAST((k), BONOBO_MONIKER_ITEM_TYPE, BonoboMonikerItemClass))
#define BONOBO_IS_MONIKER_ITEM(o)       (GTK_CHECK_TYPE ((o), BONOBO_MONIKER_ITEM_TYPE))
#define BONOBO_IS_MONIKER_ITEM_CLASS(k) (GTK_CHECK_CLASS_TYPE ((k), BONOBO_MONIKER_ITEM_TYPE))

typedef struct _BonoboMonikerItem        BonoboMonikerItem;

struct _BonoboMonikerItem {
	BonoboMoniker parent;
};

typedef struct {
	BonoboMonikerClass parent_class;
} BonoboMonikerItemClass;

GtkType bonobo_moniker_item_get_type (void);
	
END_GNOME_DECLS

#endif /* _BONOBO_MONIKER_ITEM_H_ */
